Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/azatoth/minidlna.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJustin Maggard <jmaggard@users.sourceforce.net>2011-06-25 04:39:45 +0400
committerJustin Maggard <jmaggard@users.sourceforce.net>2011-06-25 04:39:45 +0400
commitc228fba8e114bc89c6be525f80e40c77cd1c5713 (patch)
treed9c80c0d9bdf9dd38fbeb58442fc1ce5490218b7 /options.h
parent10308ba4a5ac6f0469b30bfd817ec4048f3dc82a (diff)
* Add the ability to change the root media container. (Thanks to Ivan Mironov)
Diffstat (limited to 'options.h')
-rw-r--r--options.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/options.h b/options.h
index 88a517a..b208542 100644
--- a/options.h
+++ b/options.h
@@ -52,7 +52,8 @@ enum upnpconfigoptions {
UPNPDBDIR, /* base directory to store the database and album art cache */
UPNPLOGDIR, /* base directory to store the log file */
ENABLE_TIVO, /* enable support for streaming images and music to TiVo */
- ENABLE_DLNA_STRICT /* strictly adhere to DLNA specs */
+ ENABLE_DLNA_STRICT, /* strictly adhere to DLNA specs */
+ ROOT_CONTAINER /* root ObjectID (instead of "0") */
};
/* readoptionsfile()